@@ -978,8 +978,8 @@ help_about (BonoboUIComponent *uic,
 		gdk_window_show (about->window);
 	} else {
 		about = gnome_about_new (_("Sound Recorder"), VERSION,
-					 "Copyright (C) 2002 Iain Holmes",
-					 _("A sound recorder program"),
+					 "Copyright \xc2\xa9 2002 Iain Holmes",
+					 _("A sound recorder for GNOME"),
 					 authors, NULL, NULL, NULL);
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
@@ -1088,7 +1088,7 @@ get_length (GSRWindow *window)
 
 	if (window->priv->play->sink != NULL) {
 		query_worked = gst_element_query (window->priv->play->sink,
-						  GST_PAD_QUERY_TOTAL, &format, &value);
+						  GST_QUERY_TOTAL, &format, &value);
 	}
 
 	if (query_worked) {
@@ -1158,7 +1158,7 @@ tick_callback (GSRWindow *window)
 	}
 
 	query_worked = gst_element_query (window->priv->play->sink,
-					  GST_PAD_QUERY_POSITION, 
+					  GST_QUERY_POSITION, 
 					  &format, &value);
 	if (query_worked) {
 		double percentage;
